Enum please_install::Vendor

source ·
pub enum Vendor {
Show 19 variants Apt, Yay, Yum, Pacman, Apk, Emerge, Guix, NixEnv, Pkg, Slackpkg, Cards, Dnf, Eopkg, Opkg, Urpm, Xbps, Zypper, Flatpak, Snap,
}

Variants



Apt



Yay



Yum



Pacman



Apk



Emerge



Guix



NixEnv



Pkg



Slackpkg



Cards



Dnf



Eopkg



Opkg



Urpm



Xbps



Zypper



Flatpak



Snap

Implementations

source

impl Vendor

source

pub fn new() -> Result<Self>

source

pub fn is_available(&self) -> bool

source

pub fn execute( self, command: PlsCommand, args: &str, yes: bool, su: bool, dry_run: bool, pager: Option<String>, ) -> Result<i32>